import { QuartzConfig } from "./quartz/cfg"
import * as Plugin from "./quartz/plugins"

/**
 * Quartz 4.0 Configuration
 *
 * See https://quartz.jzhao.xyz/configuration for more information.
 */

const config: QuartzConfig = {
  configuration: {
    pageTitle: "💭 Exocortex",
    pageTitleSuffix: "",
    enableSPA: false,
    enablePopovers: true,
    analytics: null,
    locale: "en-US",
    baseUrl: "cosmicflow.space/exocortex/",
    ignorePatterns: ["private", "templates", ".obsidian"],
    defaultDateType: "created",
    generateSocialImages: {
  colorScheme: "darkMode", // what colors to use for generating image, same as theme colors from config, valid values are "darkMode" and "lightMode"
  width: 1200, // width to generate with (in pixels)
  height: 630, // height to generate with (in pixels)
  excludeRoot: false, // wether to exclude "/" index path to be excluded from auto generated images (false = use auto, true = use default og image)
},
    theme: {
      fontOrigin: "local",
      cdnCaching: false,
      typography: {
        header: "Source Code Pro",
        body: "Source Code Pro",
        code: "Source Code Pro",
      },
      colors: {
        lightMode: {
	  light: "#5555a",
          lightgray: "#858585",
          gray: "#585858",
          dark: "#300020",
	  darkgray: "#140400",
          secondary: "#510426",
          tertiary: "#e91e63",
          highlight: "rgba(149, 49, 60, 0.55)",
          textHighlight: "#332a0288",
        },
        darkMode: {
          light: "#565668",
          lightgray: "#393639",
          gray: "343434",
          darkgray: "#141414",
          dark: "#1b1b1c",
          secondary: "#8b070a",
          tertiary: "#800080",
          highlight: "rgba(143, 159, 169, 0.15)",
          textHighlight: "#b3aa0288",
        },
      },
    },
  },
  plugins: {
    transformers: [
      Plugin.FrontMatter(),
      Plugin.SyntaxHighlighting({
        theme: {
          dark: "github-dark",
          light: "github-light",
        },
        keepBackground: true,
      }),
      Plugin.ObsidianFlavoredMarkdown({ enableInHtmlEmbed: false }),
      Plugin.GitHubFlavoredMarkdown(),
      Plugin.OxHugoFlavouredMarkdown(),
      Plugin.TableOfContents(),
      Plugin.Citations({
      bibliographyFile: "./References.bib"}), 
      Plugin.CrawlLinks({ markdownLinkResolution: "absolute"}),
      Plugin.Description(),
     // Plugin.Latex({ renderEngine: "katex" }),
    ],
    filters: [Plugin.RemoveDrafts()],
    emitters: [
      Plugin.AliasRedirects(),
      Plugin.ComponentResources(),
      Plugin.ContentPage(),
      Plugin.FolderPage(),
      Plugin.TagPage(),
      Plugin.ContentIndex({
        enableSiteMap: true,
        enableRSS: true,
      }),
      Plugin.Assets(),
      Plugin.Static(),
      Plugin.NotFoundPage(),
    ],
  },
}

export default config
